@@ -2,7 +2,7 @@ import ctypes
 import tkinter as tk
 import tkinter.ttk as ttk
 from ctypes import POINTER, Structure, windll
-from ctypes.wintypes import DWORD, ULONG
+from ctypes.wintypes import DWORD, ULONG, BOOL, HRGN
 
 from enum import Enum
 
@@ -196,6 +196,15 @@ class WindowComPositionAttribute(Enum):
     WCA_LAST = 23
 
 
+class DWM_BLURBEHIND(ctypes.Structure):
+    _fields_ = [
+        ('dwFlags', DWORD),
+        ('fEnable', BOOL),
+        ('hRgnBlur', HRGN),
+        ('fTransitionOnMaximized', BOOL)
+    ]
+
+
 class DwmWindowAttribute(Enum):
     DWMWA_NCRENDERING_ENABLED = 1
     DWMWA_NCRENDERING_POLICY = 2
@@ -240,6 +249,7 @@ class WindowComPositionAttributeData(Structure):
         ('SizeOfData', ULONG),
     ]
 
+
 def Error(text):
     try:
         from colorama import Fore
@@ -258,14 +268,13 @@ class DevManage(object):
         """
         self._master = GetParent(master.winfo_id())
         self._master_tk = master
-        self.DwmSetWindowAttribute = windll.dwmapi.DwmSetWindowAttribute
-        self.DwmGetWindowAttribute = windll.dwmapi.DwmGetWindowAttribute
-        self.DwmGetColorizationColor = windll.dwmapi.DwmGetColorizationColor
-        self.SetWindowCompositionAttribute = windll.user32.SetWindowCompositionAttribute
-
-        self.DWMWA_USE_IMMERSIVE_DARK_MODE = 20
-
-        self.DWMWA_WINDOW_CORNER_PREFERENCE = 33
+        self.DwmApi = ctypes.windll.dwmapi
+        self.Win32 = ctypes.windll.user32
+        self.UXTheme = ctypes.windll.uxtheme
+        self.DwmSetWindowAttribute = self.DwmApi.DwmSetWindowAttribute
+        self.DwmGetWindowAttribute = self.DwmApi.DwmGetWindowAttribute
+        self.DwmGetColorizationColor = self.DwmApi.DwmGetColorizationColor
+        self.SetWindowCompositionAttribute = self.Win32.SetWindowCompositionAttribute
 
         self.DWMWCP_DEFAULT = 0
         self.DWMWCP_DONOTROUND = 1
@@ -279,6 +288,36 @@ class DevManage(object):
         self.ACCENT_ENABLE_ACRYLICBLURBEHIND = 4,  # 亚克力效果
         self.ACCENT_INVALID_STATE = 5
 
+        self.DWM_BB_ENABLE = 0x00000001
+        self.DWM_BB_BLURREGION = 0x00000002
+        self.DWM_BB_TRANSITIONONMAXIMIZED = 0x00000004
+
+        self.DWMWA_NCRENDERING_ENABLED = 1
+        self.DWMWA_NCRENDERING_POLICY = 2
+        self.DWMWA_TRANSITIONS_FORCEDISABLED = 3
+        self.DWMWA_ALLOW_NCPAINT = 4
+        self.DWMWA_CAPTION_BUTTON_BOUNDS = 5
+        self.DWMWA_NONCLIENT_RTL_LAYOUT = 6
+        self.DWMWA_FORCE_ICONIC_REPRESENTATION = 7
+        self.DWMWA_FLIP3D_POLICY = 8
+        self.DWMWA_EXTENDED_FRAME_BOUNDS = 9
+        self.DWMWA_HAS_ICONIC_BITMAP = 10
+        self.DWMWA_DISALLOW_PEEK = 11
+        self.DWMWA_EXCLUDED_FROM_PEEK = 12
+        self.DWMWA_CLOAK = 13
+        self.DWMWA_CLOAKED = 14
+        self.DWMWA_FREEZE_REPRESENTATION = 15
+        self.DWMWA_PASSIVE_UPDATE_MODE = 16
+        self.DWMWA_USE_HOSTBACKDROPBRUSH = 17
+        self.DWMWA_CAPTION_COLOR = 19
+        self.DWMWA_USE_IMMERSIVE_DARK_MODE = 20
+        self.DWMWA_SYSTEMBACKDROP_TYPE = 23
+        self.DWMWA_LAST = 24
+        self.DWMWA_WINDOW_CORNER_PREFERENCE = 33
+        self.DWMWA_BORDER_COLOR = 34
+        self.DWMWA_TEXT_COLOR = 36
+        self.DWMWA_VISIBLE_FRAME_BORDER_THICKNESS = 37
+
     def window_screenshot(self):
         from tkcap import CAP
         return CAP(window).capture(image_name)
@@ -309,14 +348,33 @@ class DevManage(object):
         """
         设置窗口主题为明亮模式，标题栏会有所改变。
         """
-        Value = 0
-        Value = ctypes.c_int(Value)
+        Value = ctypes.c_int(0)
         self.dwm_set_window_attribute(
             self.DWMWA_USE_IMMERSIVE_DARK_MODE,
             ctypes.byref(Value),
             ctypes.sizeof(Value)
         )
 
+    def dwm_set_window_round(self, value):
+        Value = ctypes.c_int(value)
+        self.dwm_set_window_attribute(
+            self.DWMWA_WINDOW_CORNER_PREFERENCE,
+            ctypes.byref(Value),
+            ctypes.sizeof(Value)
+        )
+
+    def dwm_set_window_round_default(self):
+        self.dwm_set_window_round(self.DWMWCP_DEFAULT)
+
+    def dwm_set_window_round_donot_round(self):
+        self.dwm_set_window_round(self.DWMWCP_DONOTROUND)
+
+    def dwm_set_window_round_round(self):
+        self.dwm_set_window_round(self.DWMWCP_ROUND)
+
+    def dwm_set_window_round_round_small(self):
+        self.dwm_set_window_round(self.DWMWCP_ROUNDSMALL)
+
     def dwm_get_window_attribute(self, type, put):
         """
         获取非客户区的属性。
@@ -330,6 +388,17 @@ class DevManage(object):
     def dwm_get_colorization_color(self):
         return self.DwmGetColorizationColor()
 
+    def dwm_enable_blurbehind_window(self, flags=0x00000001, enable: bool = True, rgn_blur=1, transition_on_maximized: bool = True):
+        BlurBehid = DWM_BLURBEHIND()
+        BlurBehid.dwFlags = flags
+        BlurBehid.fEnable = enable
+        BlurBehid.hRgnBlur = rgn_blur
+        BlurBehid.TransitionOnMaximized = transition_on_maximized
+        return self.DwmApi.DwmEnableBlurBehindWindow(self._master, ctypes.byref(BlurBehid))
+
+    def dwm_is_composition_enabled(self):
+        return self.DwmApi.DwmIsCompositionEnabled()
+
     def use_mica(self, is_dark=False):
         """
         使用Windows11的云母特效。
@@ -398,12 +467,18 @@ class DevManage(object):
         """
         return UpdateWindow(self._master)
 
+    def enable_theming(self, bool: bool):
+        return self.UXTheme.EnableTheming(bool)
+
     def set_master(self, master: tk.Tk):
         """
         设置组件的父组件。
         """
         SetParent(self._master, GetParent(master.winfo_id()))
 
+    def set_window_text(self, text):
+        return SetWindowText(self._master, text)
+
     def set_window_long(self, setting):
         """
         设置窗口样式
@@ -568,6 +643,70 @@ class DevManage(object):
 
         self._master_tk.bind("<B1-Motion>", lambda event: move())
 
+    def show_window(self, state):
+        return ShowWindow(self._master, state)
+
+    def show_window_hide(self):
+        return self.show_window(SW_HIDE)
+
+    def show_window_maximize(self):
+        return self.show_window(SW_MAXIMIZE)
+
+    def show_window_minimize(self):
+        return self.show_window(SW_MINIMIZE)
+
+    def show_window_restore(self):
+        return self.show_window(SW_RESTORE)
+
+    def show_window_show(self):
+        return self.show_window(SW_SHOW)
+
+    def show_window_show_maximize(self):
+        return self.show_window(SW_SHOWMAXIMIZED)
+
+    def show_window_show_minimize(self):
+        return self.show_window(SW_SHOWMINIMIZED)
+
+    def show_window_show_minno_action(self):
+        return self.show_window(SW_SHOWMINNOACTIVE)
+
+    def show_window_show_na(self):
+        return self.show_window(SW_SHOWNA)
+
+    def show_window_show_normal(self):
+        return self.show_window(SW_SHOWNORMAL)
+
+    def close_window(self):
+        return CloseWindow(self._master)
+
+    def minimize_window(self):
+        return CloseWindow(self._master)
+
+    def enable_window(self, bool: bool):
+        return EnableWindow(self._master, bool)
+
+    def destroy_window(self):
+        return DestroyWindow(self._master)
+
+    def destroy_icon(self):
+        return DestroyIcon(self._master)
+
+    def drag_accept_files(self, bool: bool):
+        return DragAcceptFiles(self._master, bool)
+
+    def drag_finish(self):
+        return DragFinish()
+
+    def draw_menubar(self):
+        return DrawMenuBar(self._master)
+
+    def create_menu(self):
+        return CreateMenu()
+
+    def set_menu(self, menu):
+        return SetMenu(self._master,
+                       menu)
+
 
 class DevAccumulatorButton(tk.Button):
     def __init__(self):
@@ -899,6 +1038,17 @@ class DevMenuBar(tk.Frame):
         self.pack(fill=tk.X, side=tk.TOP)
 
 
+class DevMessageBox(object):
+    def __init__(self, master: tk.Tk):
+        super(DevMessageBox, self).__init__()
+        self._master = GetParent(master.winfo_id())
+
+    def show(self):
+        MessageBox(
+            self._master,
+        )
+
+
 class DevObject(object):
     def __init__(self):
         """
@@ -1460,30 +1610,7 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    from sv_ttk import use_dark_theme, use_light_theme
-
     Window = DevWindow()
-    Window.title("tkinter切换组件测试")
-    use_light_theme()
-    Theme = True
-    DevManage(Window).add_window_sysmenu()
-    def Change_Theme():
-        global Theme
-        if Theme:
-            use_dark_theme()
-            DevManage(Window).dwm_set_window_attribute_use_dark_mode()
-            DevManage(Window).use_mica_mode_dark()
-            Theme = False
-            Window.configure(background="#000000")
-            Change_Theme_Button.configure(style="Accent.TButton")
-        else:
-            use_light_theme()
-            DevManage(Window).dwm_set_window_attribute_use_light_mode()
-            DevManage(Window).use_mica_mode_light()
-            Theme = True
-            Window.configure(background="#b2b2b2")
-            Change_Theme_Button.configure(style="Accent.TButton")
-
-    Change_Theme_Button = ttk.Button(Window, text="切换主题", command=Change_Theme, style="Accent.TButton")
-    Change_Theme_Button.pack(fill="both", expand="yes", pady=10, padx=10)
+    Manage = DevManage(Window)
+    Manage.dwm_set_window_attribute_use_dark_mode()
     Window.mainloop()
