@@ -30,6 +30,10 @@ def dark():
     use_dark_theme()
 
 
+def round():
+    Manage.dwm_set_window_round_round()
+
+
 def settings():
     Stack.show_page(2)
 
@@ -53,8 +57,8 @@ LeftBar_Setting = ttk.Button(MainPage, text="Settings", command=settings)
 LeftBar_Setting.pack(fill="x", side="left", expand="yes")
 
 SettingPage = ttk.Frame(Stack)
-SettingTheme = ttk.Labelframe(SettingPage, text="Theme")
 
+SettingTheme = ttk.Labelframe(SettingPage, text="Theme")
 ThemeVar = StringVar()
 ThemeVar.set("Auto")
 AutoTheme = ttk.Radiobutton(SettingTheme, text="Auto", variable=ThemeVar, value="Auto", command=auto)
@@ -67,6 +71,19 @@ BackButton = ttk.Button(SettingTheme, text="Back", command=back)
 BackButton.pack(side="right", anchor="e", padx=10, pady=10, ipadx=10)
 SettingTheme.pack(fill="x", side="top", padx=10, pady=10)
 
+SettingRound = ttk.Labelframe(SettingPage, text="Round")
+RoundVar = StringVar()
+RoundVar.set("Round")
+Round = ttk.Radiobutton(SettingRound, text="Round", variable=RoundVar, value="Round", command=round)
+Round.pack(side="left", padx=10, pady=10)
+RoundSmall = ttk.Radiobutton(SettingRound, text="Round Small", variable=RoundVar, value="Round Small", command=light)
+RoundSmall.pack(side="left", padx=10, pady=10)
+DonotRound = ttk.Radiobutton(SettingRound, text="Donot Round", variable=RoundVar, value="Donot Round", command=dark)
+DonotRound.pack(side="left", padx=10, pady=10)
+BackButton2 = ttk.Button(SettingRound, text="Back", command=back)
+BackButton2.pack(side="right", anchor="e", padx=10, pady=10, ipadx=10)
+SettingRound.pack(fill="x", side="top", padx=10, pady=10)
+
 Stack.add_page(StartPage, 0)
 Stack.add_page(MainPage, 1)
 Stack.add_page(SettingPage, 2)
